@@ -314,16 +314,33 @@ def interceptor_db_con(fn, db_type, *args, **kwargs):
     
     return callback
 
+def addQuote(arg_dict):
+    quoted_dict = dict()
+
+    for k, v in arg_dict.items():
+        if isinstance(v, str):
+            quoted_dict[k] = "'" + v.replace("'", "\\'") + "'"
+        else:
+            quoted_dict[k] = v
+
+    return quoted_dict
 
 def interceptor_db_execute(fn, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
-    
+
     self = args[0]
+    query = None
+    if len(args) > 2 and type(args[2]) == dict and args[2]:
+        try:
+            query = args[1] % addQuote(args[2])
+        except Exception as e:
+            pass
     try:
-        query = args[1].decode()
+        if not query:
+            query = args[1].decode()
     except Exception as e:
         query = args[1]
-    
+
     if not query or ctx.active_sqlhash:
         return fn(*args, **kwargs)
     
