@@ -35,6 +35,7 @@ DEFINITION = {
     ],
     'database_toolkit': [
         ('sqlalchemy.orm.session', 'instrument_sqlalchemy'),
+        ('sqlalchemy.engine.default', 'instrument_sqlalchemy_engine'),
     ],
     'application_wsgi': [
         ('', ''),
@@ -83,7 +84,7 @@ DEFINITION = {
     'amqp_kombu':[
         ('kombu','instrument_kombu'),
     ],
-    'amqp_pika':[
-        ('pika.channel','instrument_pika'),
-    ],
+    # 'amqp_pika':[
+    #     ('pika.channel','instrument_pika'),
+    # ],
 }
